/*
**==============================================================================
**
** Microsoft Public License (Ms-PL)
** 
** This license governs use of the accompanying software. If you use the 
** software, you accept this license. If you do not accept the license, do not 
** use the software.
**
** 1. Definitions
** The terms "reproduce," "reproduction," "derivative works," and 
** "distribution" have the same meaning here as under U.S. copyright law.
** A "contribution" is the original software, or any additions or changes to 
** the software.
** A "contributor" is any person that distributes its contribution under this 
** license.
** "Licensed patents" are a contributor's patent claims that read directly on 
** its contribution.
**
** 2. Grant of Rights
** (A) Copyright Grant- Subject to the terms of this license, including the 
** license conditions and limitations in section 3, each contributor grants you
** a non-exclusive, worldwide, royalty-free copyright license to reproduce its
** contribution, prepare derivative works of its contribution, and distribute 
** its contribution or any derivative works that you create.
** (B) Patent Grant- Subject to the terms of this license, including the 
** license conditions and limitations in section 3, each contributor grants you
** a non-exclusive, worldwide, royalty-free license under its licensed patents
** to make, have made, use, sell, offer for sale, import, and/or otherwise 
** dispose of its contribution in the software or derivative works of the 
** contribution in the software.
**
** 3. Conditions and Limitations
** (A) No Trademark License- This license does not grant you rights to use any 
** contributors' name, logo, or trademarks.
** (B) If you bring a patent claim against any contributor over patents that 
** you claim are infringed by the software, your patent license from such 
** contributor to the software ends automatically.
** (C) If you distribute any portion of the software, you must retain all 
** copyright, patent, trademark, and attribution notices that are present in 
** the software.
** (D) If you distribute any portion of the software in source code form, you 
** may do so only under this license by including a complete copy of this 
** license with your distribution. If you distribute any portion of the 
** software in compiled or object code form, you may only do so under a license
** that complies with this license.
** (E) The software is licensed "as-is." You bear the risk of using it. The 
** contributors give no express warranties, guarantees or conditions. You may 
** have additional consumer rights under your local laws which this license 
** cannot change. To the extent permitted under your local laws, the 
** contributors exclude the implied warranties of merchantability, fitness for 
** a particular purpose and non-infringement.
**
**==============================================================================
*/
/**
    \file        

    \brief       Contains the implementation of the log file configurator.

    \date        2008-07-21 15:10:29

*/
/*----------------------------------------------------------------------------*/

#include "scxlogconfigreader.h"

#include <scxcorelib/scxfile.h>
#include <scxcorelib/scxlogpolicy.h>
#include <scxcorelib/stringaid.h>
#include <vector>

namespace SCXCoreLib
{

    
    /*----------------------------------------------------------------------------*/
    /**
        Given a string, translates it to an SCXLogSeverity.
        Recognized strings are:

        \li HYSTERICAL
        \li TRACE
        \li INFO
        \li WARNING
        \li ERROR
        \li SUPPRESS

        If the string does not match any of these, eNotSet is returned.

        \param[in] severityString String to translate.
        \returns SCXLogSeverity representing the severity string supplied.
    */
    SCXLogSeverity SCXLogConfigReader_TranslateSeverityString(const std::wstring& severityString)
    {
        if (L"HYSTERICAL" == severityString) {
            return eHysterical;
        } else if (L"TRACE" == severityString) {
            return eTrace;
        } else if (L"INFO" == severityString) {
            return eInfo;
        } else if (L"WARNING" == severityString) {
            return eWarning;
        } else if (L"ERROR" == severityString) {
            return eError;
        } else if (L"SUPPRESS" == severityString) {
            return eSuppress;
        } else {
            return eNotSet;
        }
    }

    /*----------------------------------------------------------------------------*/
    /**
        Given a log severity, translates it to an string.

        \li NOTSET
        \li HYSTERICAL
        \li TRACE
        \li INFO
        \li WARNING
        \li ERROR
        \li SUPPRESS

        \param[in] severity Severity to translate.
        \returns String representing the severity supplied.
    */
    std::wstring SCXLogConfigReader_SeverityToString(SCXLogSeverity severity)
    {
        switch (severity)
        {
        case eHysterical:
            return L"HYSTERICAL";
        case eTrace:
            return L"TRACE";
        case eInfo:
            return L"INFO";
        case eWarning:
            return L"WARNING";
        case eError:
            return L"ERROR";
        case eSuppress:
            return L"SUPPRESS";
        case eNotSet:
        case eSeverityMax:
        default:
            return L"NOTSET";
        }
    }


} /* namespace SCXCoreLib */
/*----------------------------E-N-D---O-F---F-I-L-E---------------------------*/
