/*
**==============================================================================
**
** Microsoft Public License (Ms-PL)
** 
** This license governs use of the accompanying software. If you use the 
** software, you accept this license. If you do not accept the license, do not 
** use the software.
**
** 1. Definitions
** The terms "reproduce," "reproduction," "derivative works," and 
** "distribution" have the same meaning here as under U.S. copyright law.
** A "contribution" is the original software, or any additions or changes to 
** the software.
** A "contributor" is any person that distributes its contribution under this 
** license.
** "Licensed patents" are a contributor's patent claims that read directly on 
** its contribution.
**
** 2. Grant of Rights
** (A) Copyright Grant- Subject to the terms of this license, including the 
** license conditions and limitations in section 3, each contributor grants you
** a non-exclusive, worldwide, royalty-free copyright license to reproduce its
** contribution, prepare derivative works of its contribution, and distribute 
** its contribution or any derivative works that you create.
** (B) Patent Grant- Subject to the terms of this license, including the 
** license conditions and limitations in section 3, each contributor grants you
** a non-exclusive, worldwide, royalty-free license under its licensed patents
** to make, have made, use, sell, offer for sale, import, and/or otherwise 
** dispose of its contribution in the software or derivative works of the 
** contribution in the software.
**
** 3. Conditions and Limitations
** (A) No Trademark License- This license does not grant you rights to use any 
** contributors' name, logo, or trademarks.
** (B) If you bring a patent claim against any contributor over patents that 
** you claim are infringed by the software, your patent license from such 
** contributor to the software ends automatically.
** (C) If you distribute any portion of the software, you must retain all 
** copyright, patent, trademark, and attribution notices that are present in 
** the software.
** (D) If you distribute any portion of the software in source code form, you 
** may do so only under this license by including a complete copy of this 
** license with your distribution. If you distribute any portion of the 
** software in compiled or object code form, you may only do so under a license
** that complies with this license.
** (E) The software is licensed "as-is." You bear the risk of using it. The 
** contributors give no express warranties, guarantees or conditions. You may 
** have additional consumer rights under your local laws which this license 
** cannot change. To the extent permitted under your local laws, the 
** contributors exclude the implied warranties of merchantability, fitness for 
** a particular purpose and non-infringement.
**
**==============================================================================
*/
/**
    \file        

    \brief       Contains the definition of log file configurator class.

    \date        2008-07-22 08:55:15

*/
/*----------------------------------------------------------------------------*/
#ifndef SCXLOGFILECONFIGURATOR_H
#define SCXLOGFILECONFIGURATOR_H

#include <scxcorelib/scxlog.h>
#include <scxcorelib/scxhandle.h>
#include <scxcorelib/scxthread.h>
#include "scxlogfilebackend.h"
#include "scxlogmediator.h"
#include "scxlogconfigreader.h"

#include <list>

namespace SCXCoreLib
{
    /*----------------------------------------------------------------------------*/
    /**
        Implementation of the log configurator interface.
    */
    class SCXLogFileConfigurator : public SCXLogConfiguratorIf
    {
        typedef std::list<SCXHandle<SCXLogBackend> > BackendList; //!< List of backends
    public:
        SCXLogFileConfigurator(SCXHandle<SCXLogMediator> mediator,
                               const SCXFilePath& configFilePath,
                               const SCXThreadLockHandle& lock = ThreadLockHandleGet(),
                               scxulong configRefreshRate = 10000);

        virtual void SetSeverityThreshold(const std::wstring& module, SCXLogSeverity newThreshold);
        virtual void ClearSeverityThreshold(const std::wstring& module);
        virtual unsigned int GetConfigVersion() const;
        virtual void RestoreConfiguration();
        virtual std::wstring GetMinActiveSeverityThreshold() const;
        virtual ~SCXLogFileConfigurator();

        // interface to the config-reader
        bool SetSeverityThreshold(SCXHandle<SCXLogBackend> backend, const std::wstring& module, SCXLogSeverity newThreshold);
        SCXHandle<SCXLogBackend>  Create(const std::wstring& name);
        void    Add( SCXHandle<SCXLogBackend> backend );
        
    private:
        /**
            private assignment operator.
        */
        SCXLogFileConfigurator& operator=(const SCXLogFileConfigurator&) { return *this; }
        bool ParseConfigFile();
        bool IsConfigurationChanged() const;

        SCXHandle<SCXLogMediator> m_Mediator; //!< Mediator to configure.
        BackendList m_Backends; //!< Configured backends.
        const SCXFilePath m_ConfigFilePath; //!< File path of config file.
        unsigned int m_ConfigVersion; //!< Current config version.
        SCXThreadLockHandle m_lock; //!< Thread lock synchronizing access to internal data.
        scxulong m_ConfigRefreshRate; //!< The interval the configuration thread checks for new configuration.
        SCXHandle<SCXThread> m_ConfigUpdateThread; //!< Pointer to thread.
        SCXFileInfo m_ConfFile; //!< Contains cached information about the configuration file.
        SCXLogSeverity m_MinActiveSeverityThreshold; //!< Minimum severity threshold set for any module in the framework.
        static void ConfigUpdateThreadBody(SCXCoreLib::SCXThreadParamHandle& param);
    };
}

#endif /* SCXLOGMEDIATORSIMPLE_H */
/*----------------------------E-N-D---O-F---F-I-L-E---------------------------*/
