/*
**==============================================================================
**
** Microsoft Public License (Ms-PL)
** 
** This license governs use of the accompanying software. If you use the 
** software, you accept this license. If you do not accept the license, do not 
** use the software.
**
** 1. Definitions
** The terms "reproduce," "reproduction," "derivative works," and 
** "distribution" have the same meaning here as under U.S. copyright law.
** A "contribution" is the original software, or any additions or changes to 
** the software.
** A "contributor" is any person that distributes its contribution under this 
** license.
** "Licensed patents" are a contributor's patent claims that read directly on 
** its contribution.
**
** 2. Grant of Rights
** (A) Copyright Grant- Subject to the terms of this license, including the 
** license conditions and limitations in section 3, each contributor grants you
** a non-exclusive, worldwide, royalty-free copyright license to reproduce its
** contribution, prepare derivative works of its contribution, and distribute 
** its contribution or any derivative works that you create.
** (B) Patent Grant- Subject to the terms of this license, including the 
** license conditions and limitations in section 3, each contributor grants you
** a non-exclusive, worldwide, royalty-free license under its licensed patents
** to make, have made, use, sell, offer for sale, import, and/or otherwise 
** dispose of its contribution in the software or derivative works of the 
** contribution in the software.
**
** 3. Conditions and Limitations
** (A) No Trademark License- This license does not grant you rights to use any 
** contributors' name, logo, or trademarks.
** (B) If you bring a patent claim against any contributor over patents that 
** you claim are infringed by the software, your patent license from such 
** contributor to the software ends automatically.
** (C) If you distribute any portion of the software, you must retain all 
** copyright, patent, trademark, and attribution notices that are present in 
** the software.
** (D) If you distribute any portion of the software in source code form, you 
** may do so only under this license by including a complete copy of this 
** license with your distribution. If you distribute any portion of the 
** software in compiled or object code form, you may only do so under a license
** that complies with this license.
** (E) The software is licensed "as-is." You bear the risk of using it. The 
** contributors give no express warranties, guarantees or conditions. You may 
** have additional consumer rights under your local laws which this license 
** cannot change. To the extent permitted under your local laws, the 
** contributors exclude the implied warranties of merchantability, fitness for 
** a particular purpose and non-infringement.
**
**==============================================================================
*/
/**
    \file

    \brief       Specification of facets needed to make STL internalization behave the
                 same on scx supported platforms

    \date        08-08-05 10:18:00


*/
/*----------------------------------------------------------------------------*/
#ifndef SCXFACETS_H
#define SCXFACETS_H

#include <locale>
#include <wchar.h>
#include <iostream>
#include <vector>

namespace SCXCoreLib {

#if defined(linux) || defined(macos)
typedef mbstate_t &do_length_mbstateRef;        //!< Declaration on platform
#else
typedef const mbstate_t &do_length_mbstateRef;  //!< Declaration on platform
#endif

//! STL facet to convert between internal wide representation and an external
//! representation acoording to current locale
class SCXDefaultEncodingFacet : public std::codecvt<wchar_t, char, mbstate_t>   {
public:

    virtual bool do_always_noconv() const throw ();
    virtual int do_encoding() const throw ();
    virtual int do_length(do_length_mbstateRef state, const char *begin, const char *end, size_t maxWideCharCount) const;

    virtual std::codecvt_base::result do_in(mbstate_t &state,
               const char *fromBegin, const char *fromEnd, const char *&fromNext,
               wchar_t *toBegin, wchar_t *toEnd, wchar_t *&toNext) const;

    virtual std::codecvt_base::result do_out(mbstate_t &state,
               const wchar_t *fromBegin, const wchar_t *fromEnd, const wchar_t *&fromNext,
               char *toBegin, char *toEnd, char *&toNext) const;

    virtual std::codecvt_base::result do_unshift(mbstate_t &state,
            char *toBegin, char *toEnd, char *&toNext) const;
};


}
#endif /* SCXFACETS_H */
/*----------------------------E-N-D---O-F---F-I-L-E---------------------------*/
