/*
**==============================================================================
**
** Microsoft Public License (Ms-PL)
** 
** This license governs use of the accompanying software. If you use the 
** software, you accept this license. If you do not accept the license, do not 
** use the software.
**
** 1. Definitions
** The terms "reproduce," "reproduction," "derivative works," and 
** "distribution" have the same meaning here as under U.S. copyright law.
** A "contribution" is the original software, or any additions or changes to 
** the software.
** A "contributor" is any person that distributes its contribution under this 
** license.
** "Licensed patents" are a contributor's patent claims that read directly on 
** its contribution.
**
** 2. Grant of Rights
** (A) Copyright Grant- Subject to the terms of this license, including the 
** license conditions and limitations in section 3, each contributor grants you
** a non-exclusive, worldwide, royalty-free copyright license to reproduce its
** contribution, prepare derivative works of its contribution, and distribute 
** its contribution or any derivative works that you create.
** (B) Patent Grant- Subject to the terms of this license, including the 
** license conditions and limitations in section 3, each contributor grants you
** a non-exclusive, worldwide, royalty-free license under its licensed patents
** to make, have made, use, sell, offer for sale, import, and/or otherwise 
** dispose of its contribution in the software or derivative works of the 
** contribution in the software.
**
** 3. Conditions and Limitations
** (A) No Trademark License- This license does not grant you rights to use any 
** contributors' name, logo, or trademarks.
** (B) If you bring a patent claim against any contributor over patents that 
** you claim are infringed by the software, your patent license from such 
** contributor to the software ends automatically.
** (C) If you distribute any portion of the software, you must retain all 
** copyright, patent, trademark, and attribution notices that are present in 
** the software.
** (D) If you distribute any portion of the software in source code form, you 
** may do so only under this license by including a complete copy of this 
** license with your distribution. If you distribute any portion of the 
** software in compiled or object code form, you may only do so under a license
** that complies with this license.
** (E) The software is licensed "as-is." You bear the risk of using it. The 
** contributors give no express warranties, guarantees or conditions. You may 
** have additional consumer rights under your local laws which this license 
** cannot change. To the extent permitted under your local laws, the 
** contributors exclude the implied warranties of merchantability, fitness for 
** a particular purpose and non-infringement.
**
**==============================================================================
*/
/**
    \file
 
    \brief     Defines the public interface for the filepath PAL.

    \date      2007-05-14 12:34:56
 

*/
/*----------------------------------------------------------------------------*/
#ifndef SCXFILEPATH_H
#define SCXFILEPATH_H

#include <string>

namespace SCXCoreLib
{
    /*----------------------------------------------------------------------------*/
    /**
       SCXFilePath implements a platform-independent file/folder name handler. 
    
       \date        2007-05-14 12:34:56
    
      In order to make sure file paths are handled in a consistant 
      way, this class should be used for all path handling.
    
    */
    class SCXFilePath
    {
    public:
        SCXFilePath(void);
        SCXFilePath(const SCXFilePath&);
        SCXFilePath(const std::wstring&);
        SCXFilePath(const wchar_t*);

        const std::wstring DumpString() const;

    public:
        void Set(const std::wstring&);
        void SetFilename(const std::wstring&);
        void SetFilesuffix(const std::wstring&);
        void SetDirectory(const std::wstring&);

        const std::wstring Get(void) const;
        const std::wstring& GetFilename(void) const;
        const std::wstring GetFilesuffix(void) const;
        const std::wstring& GetDirectory(void) const;

        void Append(const std::wstring&);
        void AppendDirectory(const std::wstring&);
        
        static wchar_t GetFolderSeparator();

        operator std::wstring ();
        SCXFilePath& operator+= (const std::wstring&);
        SCXFilePath& operator= (const SCXFilePath&);
        SCXFilePath& operator= (const std::wstring&);
        friend bool operator== (const SCXFilePath&, const SCXFilePath&);
        friend bool operator!= (const SCXFilePath&, const SCXFilePath&);

    protected:
        //! Internal bitmask enum specifying action of ReplaceSeparators()
        enum SeparatorReplaceFlagType
        {
            eSeparatorReplaceFolder = 0x1,
            eSeparatorReplaceSuffix = 0x2,
            eSeparatorReplaceAll = eSeparatorReplaceFolder | eSeparatorReplaceSuffix
        };
            
        void ReplaceSeparators(SeparatorReplaceFlagType flag);

    protected:
        //! Contains the directory name at any one time
        std::wstring m_directory;
        //! Contains the file name 
        std::wstring m_filename;

        static const wchar_t s_folderSeparator;
        static const wchar_t* s_folderSeparatorsAllowed;
        static const wchar_t s_suffixSeparator;
        static const wchar_t* s_suffixSeparatorsAllowed;
    };
} /* namespace SCXCoreLib */

#endif /* SCXFILEPATH_H */
/*------------------E-N-D---O-F---F-I-L-E-------------------------------*/
