/*
**==============================================================================
**
** Microsoft Public License (Ms-PL)
** 
** This license governs use of the accompanying software. If you use the 
** software, you accept this license. If you do not accept the license, do not 
** use the software.
**
** 1. Definitions
** The terms "reproduce," "reproduction," "derivative works," and 
** "distribution" have the same meaning here as under U.S. copyright law.
** A "contribution" is the original software, or any additions or changes to 
** the software.
** A "contributor" is any person that distributes its contribution under this 
** license.
** "Licensed patents" are a contributor's patent claims that read directly on 
** its contribution.
**
** 2. Grant of Rights
** (A) Copyright Grant- Subject to the terms of this license, including the 
** license conditions and limitations in section 3, each contributor grants you
** a non-exclusive, worldwide, royalty-free copyright license to reproduce its
** contribution, prepare derivative works of its contribution, and distribute 
** its contribution or any derivative works that you create.
** (B) Patent Grant- Subject to the terms of this license, including the 
** license conditions and limitations in section 3, each contributor grants you
** a non-exclusive, worldwide, royalty-free license under its licensed patents
** to make, have made, use, sell, offer for sale, import, and/or otherwise 
** dispose of its contribution in the software or derivative works of the 
** contribution in the software.
**
** 3. Conditions and Limitations
** (A) No Trademark License- This license does not grant you rights to use any 
** contributors' name, logo, or trademarks.
** (B) If you bring a patent claim against any contributor over patents that 
** you claim are infringed by the software, your patent license from such 
** contributor to the software ends automatically.
** (C) If you distribute any portion of the software, you must retain all 
** copyright, patent, trademark, and attribution notices that are present in 
** the software.
** (D) If you distribute any portion of the software in source code form, you 
** may do so only under this license by including a complete copy of this 
** license with your distribution. If you distribute any portion of the 
** software in compiled or object code form, you may only do so under a license
** that complies with this license.
** (E) The software is licensed "as-is." You bear the risk of using it. The 
** contributors give no express warranties, guarantees or conditions. You may 
** have additional consumer rights under your local laws which this license 
** cannot change. To the extent permitted under your local laws, the 
** contributors exclude the implied warranties of merchantability, fitness for 
** a particular purpose and non-infringement.
**
**==============================================================================
*/
/**
    \file        

    \brief       Defines the static disk information instance PAL for logical disks.
    
    \date        2008-03-19 11:42:00
    
*/
/*----------------------------------------------------------------------------*/
#ifndef STATICLOGICALDISKINSTANCE_H
#define STATICLOGICALDISKINSTANCE_H

#include <scxsystemlib/entityinstance.h>
#include <scxsystemlib/diskdepend.h>
#include <scxcorelib/scxlog.h>
#include <scxcorelib/scxhandle.h>

namespace SCXSystemLib
{
/*----------------------------------------------------------------------------*/
/**
    Represents a single disk instance with static data.
*/
    class StaticLogicalDiskInstance : public EntityInstance
    {
        friend class StaticLogicalDiskEnumeration;

    public:
        StaticLogicalDiskInstance(SCXCoreLib::SCXHandle<DiskDepend> deps);
        virtual ~StaticLogicalDiskInstance();

        bool GetHealthState(bool& healthy) const;
        bool GetDeviceName(std::wstring& value) const;
        bool GetDeviceID(std::wstring& value) const;
        bool GetMountpoint(std::wstring& value) const;
        bool GetSizeInBytes(scxulong& value) const;
        bool GetCompressionMethod(std::wstring& value) const;
        bool GetIsReadOnly(bool& value) const;
        bool GetEncryptionMethod(std::wstring& value) const;
        bool GetPersistenceType(int& value) const;
        bool GetAvailableSpaceInBytes(scxulong& value) const;
        bool GetNumberOfFiles(scxulong& value) const;
        bool GetIsCaseSensitive(bool& value) const;
        bool GetIsCasePreserved(bool& value) const;
        bool GetCodeSet(int& value) const;
        bool GetMaxFilenameLen(scxulong& value) const;
        bool GetFileSystemType(std::wstring& value) const;
        bool GetBlockSize(scxulong& value) const;

        virtual const std::wstring DumpString() const;
        virtual void Update();

    private:
        //! Private constructor (this should never be called!)
        StaticLogicalDiskInstance();            //!< Default constructor (intentionally not implemented)

        virtual void UpdateDefaults();

        SCXCoreLib::SCXHandle<DiskDepend> m_deps;//!< StaticDiskDepend object
        SCXCoreLib::SCXLogHandle m_log;         //!< Log handle
        bool m_online;                          //!< Tells if disk is still connected
        std::wstring m_device;                  //!< Device ID (i.e. /dev/sda1)
        std::wstring m_mountPoint;              //!< Mount point of device (i.e. "/")
        std::wstring m_fileSystemType;          //!< File system type (internal use only)
        scxulong m_sizeInBytes;                 //!< Total size, in bytes
        std::wstring m_compressionMethod;       //!< Compression method - Unknown/Compressed/Not Compressed
        bool m_isReadOnly;                      //!< Is file system read-only?
        std::wstring m_encryptionMethod;        //!< Encryption method - Unknown/Encrypted/Not Encrypted
        int m_persistenceType;                  //!< Persistence type (0-4 for Unknown/Other/Persistent/Temporary/External
        scxulong m_availableSpace;              //!< Available space on volume
        bool m_isNumFilesSupported;             //!< Does this file system support number of files?
        scxulong m_numFiles;                    //!< Number of files stored
        bool m_isCaseSensitive;                 //!< Is file system case sensitive?
        bool m_isCasePreserved;                 //!< Is file system case preserved?
        int m_codeSet;                          //!< Code set (0-8 for Unknown/Other/ASCII/Unicode/ISO2022/ISO8859/Extended UNIX Code/UTF-8/UCS-2
        scxulong m_maxFilenameLen;              //!< Maximum file name length
        scxulong m_blockSize;                   //!< Block size
    };
} /* namespace SCXSystemLib */
#endif /* STATICLOGICALDISKINSTANCE_H */
/*----------------------------E-N-D---O-F---F-I-L-E---------------------------*/
